==> 0.4.5.1-stable.tar.gz: opensim/OpenSim/Region/Storage/OpenSim.DataStore.NullStorage/NullDataStore.cs <==
/*
* Copyright (c) Contributors, http://opensimulator.org/
* See CONTRIBUTORS.TXT for a full list of copyright holders.
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions are met:
*     * Redistributions of source code must retain the above copyright
*       notice, this list of conditions and the following disclaimer.
*     * Redistributions in binary form must reproduce the above copyright
*       notice, this list of conditions and the following disclaimer in the
*       documentation and/or other materials provided with the distribution.
*     * Neither the name of the OpenSim Project nor the
*       names of its contributors may be used to endorse or promote products
*       derived from this software without specific prior written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE DEVELOPERS AS IS AND ANY
* EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
* DISCLAIMED. IN NO EVENT SHALL THE CONTRIBUTORS BE LIABLE FOR ANY
* DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
* (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
* LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
* ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
* 
*/

using System.Collections.Generic;
using libsecondlife;
using OpenSim.Region.Environment.Interfaces;
using OpenSim.Region.Environment.LandManagement;
using OpenSim.Region.Environment.Scenes;

namespace OpenSim.DataStore.NullStorage
{
    public class NullDataStore : IRegionDataStore
    {
        public void Initialise(string dbfile)
        {
            return;
        }

        public void StoreObject(SceneObjectGroup obj, LLUUID regionUUID)
        {
        }

        public void RemoveObject(LLUUID obj, LLUUID regionUUID)
        {
        }

        public List<SceneObjectGroup> LoadObjects(LLUUID regionUUID)
        {
            return new List<SceneObjectGroup>();
        }

        public void StoreTerrain(double[,] ter, LLUUID regionID)
        {
        }

        public double[,] LoadTerrain(LLUUID regionID)
        {
            return null;
        }

        public void RemoveLandObject(uint id)
        {
        }

        public void StoreParcel(Land land)
        {
        }

        public List<Land> LoadLandObjects()
        {
            return new List<Land>();
        }

        public void Shutdown()
        {
        }
    }
}

==> 0.4.5.2-stable.tar.gz: opensim/OpenSim/Region/Storage/OpenSim.DataStore.NullStorage/NullDataStore.cs <==
/*
* Copyright (c) Contributors, http://opensimulator.org/
* See CONTRIBUTORS.TXT for a full list of copyright holders.
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions are met:
*     * Redistributions of source code must retain the above copyright
*       notice, this list of conditions and the following disclaimer.
*     * Redistributions in binary form must reproduce the above copyright
*       notice, this list of conditions and the following disclaimer in the
*       documentation and/or other materials provided with the distribution.
*     * Neither the name of the OpenSim Project nor the
*       names of its contributors may be used to endorse or promote products
*       derived from this software without specific prior written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE DEVELOPERS AS IS AND ANY
* EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
* DISCLAIMED. IN NO EVENT SHALL THE CONTRIBUTORS BE LIABLE FOR ANY
* DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
* (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
* LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
* ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
* 
*/

using System.Collections.Generic;
using libsecondlife;
using OpenSim.Region.Environment.Interfaces;
using OpenSim.Region.Environment.LandManagement;
using OpenSim.Region.Environment.Scenes;

namespace OpenSim.DataStore.NullStorage
{
    public class NullDataStore : IRegionDataStore
    {
        public void Initialise(string dbfile)
        {
            return;
        }

        public void StoreObject(SceneObjectGroup obj, LLUUID regionUUID)
        {
        }

        public void RemoveObject(LLUUID obj, LLUUID regionUUID)
        {
        }

        public List<SceneObjectGroup> LoadObjects(LLUUID regionUUID)
        {
            return new List<SceneObjectGroup>();
        }

        public void StoreTerrain(double[,] ter, LLUUID regionID)
        {
        }

        public double[,] LoadTerrain(LLUUID regionID)
        {
            return null;
        }

        public void RemoveLandObject(LLUUID globalID)
        {
        }

        public void StoreLandObject(Land land, LLUUID regionUUID)
        {
        }

        public List<Framework.LandData> LoadLandObjects(LLUUID regionUUID)
        {
            return new List<Framework.LandData>();
        }

        public void Shutdown()
        {
        }
    }
}
